# You can change filename/path
# These are two example nodes (nodes are functions)
def node_function_1(data, multiplier) -> int:
    return data * multiplier

def node_function_2(data, offset) -> int:
    return data + offset